party-notes
===========
This module adds a notes page to the party type. 
You can add any text to a party.

Install
=======

pip install mds-party-notes

Requires
========
- Tryton 5.0

Changes
=======

*5.0.0 - 17.01.2019*

- compatibility to Tryton 5.0
